from datetime import datetime


class User:
    """
    Represents a user in the system.

    :param user_id: The unique identifier of the user.
    :type user_id: int
    :param username: The username of the user.
    :type username: str
    :param displayname: The display name of the user.
    :type displayname: str
    :param email: The email address of the user.
    :type email: str
    :param password: The hashed password of the user.
    :type password: str
    :param role_id: The role ID of the user. Defaults to 1.
    :type role_id: int
    :param creation_date: The date and time when the user was created.
    :type creation_date: datetime
    
    """

    def __init__(
        self,
        user_id: str = None,
        username: str = None,
        displayname: str = None,
        email: str = None,
        password: str = None,
        role_id: int = 1,
        creation_date: datetime = None,
    ):
        self.user_id = user_id
        self.username = username
        self.displayname = displayname
        self.email = email
        self.password = password
        self.role_id = role_id
        self.creation_date = creation_date

    def __repr__(self):
        return f"User(id={self.user_id}, username={self.username}, displayname={self.displayname}, email={self.email}, password={self.password}, role_id={self.role_id}, creation_date={self.creation_date})"
